pub async fn require_admin(
__arg0: State<App>,
__arg1: Auth,
req: Request,
next: Next,
) -> Result<Response, Error>Expand description
Middleware that checks if the current user has admin role (SADM)
This middleware is simpler than check_perm_profile as it doesn’t require
a path parameter - it just checks if the authenticated user has admin privileges.